@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -19,7 +19,7 @@ This submodule contains workflow-based commands for the dx
 command-line client.
 '''
 
-from __future__ import print_function
+from __future__ import (print_function, unicode_literals)
 
 import os, sys
 
