@@ -180,11 +180,14 @@ def exit_with_exc_info(code=1, message='', print_tb=False, exception=None):
     :type print_tb: boolean
     :type exception: an exception to use in place of the last exception raised
     '''
-    exc_type, exc_value = (exception.__class__.__name__, exception) \
+    exc_type, exc_value = (exception.__class__, exception) \
                           if exception is not None else sys.exc_info()[:2]
+
     if exc_type is not None:
         if print_tb:
             traceback.print_exc()
+        elif isinstance(exc_value, KeyboardInterrupt):
+            sys.stderr.write('^C\n')
         else:
             for line in traceback.format_exception_only(exc_type, exc_value):
                 sys.stderr.write(line)
@@ -228,9 +231,13 @@ def err_exit(message='', code=None, expected_exceptions=default_expected_excepti
         message = arg_parser.prog + ": " + message
 
     exc = exception if exception is not None else sys.exc_info()[1]
-    if isinstance(exc, expected_exceptions):
+    if isinstance(exc, SystemExit):
+        raise
+    elif isinstance(exc, expected_exceptions):
         exit_with_exc_info(EXPECTED_ERR_EXIT_STATUS, message, print_tb=dxpy._DEBUG > 0, exception=exception)
     elif ignore_sigpipe and isinstance(exc, IOError) and getattr(exc, 'errno', None) == errno.EPIPE:
+        if dxpy._DEBUG > 0:
+            print("Broken pipe", file=sys.stderr)
         sys.exit(3)
     else:
         if code is None:
