@@ -21,7 +21,8 @@ Utilities for client-side usage of the streaming log API
 
 from __future__ import print_function, unicode_literals
 
-import json, logging
+import json, logging, time
+from collections import defaultdict
 
 #from ws4py.client.threadedclient import WebSocketClient
 from ws4py.client import WebSocketBaseClient
@@ -30,7 +31,8 @@ import dxpy
 from .describe import get_find_executions_string
 from ..exceptions import err_exit
 
-logging.getLogger('ws4py').setLevel(logging.ERROR)
+logger = logging.getLogger('ws4py')
+logger.setLevel(logging.WARN)
 
 class DXJobLogStreamingException(Exception):
     pass
@@ -40,17 +42,19 @@ class DXJobLogStreamClient(WebSocketBaseClient):
                  print_job_info=True):
         self.job_id = job_id
         self.seen_jobs = {}
+        self.last_seen_log_lines = defaultdict(dict)
+        self.skipped_messages = 0
         self.input_params = input_params
         self.msg_output_format = msg_output_format
         self.msg_callback = msg_callback
         self.print_job_info = print_job_info
         self.closed_code, self.closed_reason = None, None
         ws_proto = 'wss' if dxpy.APISERVER_PROTOCOL == 'https' else 'ws'
-        url = "{protocol}://{host}:{port}/{job_id}/getLog/websocket".format(protocol=ws_proto,
-                                                                            host=dxpy.APISERVER_HOST,
-                                                                            port=dxpy.APISERVER_PORT,
-                                                                            job_id=job_id)
-        WebSocketBaseClient.__init__(self, url, protocols=None, extensions=None)
+        self.url = "{protocol}://{host}:{port}/{job_id}/getLog/websocket".format(protocol=ws_proto,
+                                                                                 host=dxpy.APISERVER_HOST,
+                                                                                 port=dxpy.APISERVER_PORT,
+                                                                                 job_id=job_id)
+        WebSocketBaseClient.__init__(self, self.url, protocols=None, extensions=None)
 
     def handshake_ok(self):
         self.run()
@@ -61,6 +65,31 @@ class DXJobLogStreamClient(WebSocketBaseClient):
         args.update(self.input_params)
         self.send(json.dumps(args))
 
+    def reconnect(self):
+        # Instead of trying to reconnect in a retry loop with backoff, run an API call that will do the same
+        # and block while it retries.
+        time.sleep(1)
+        dxpy.describe(self.job_id)
+        WebSocketBaseClient.__init__(self, self.url, protocols=None, extensions=None)
+        self.connect()
+
+    def terminate(self):
+        if self.stream and self.stream.closing and self.stream.closing.code == 1001 \
+           and self.stream.closing.reason == "Server restart, please reconnect later":
+            # Clean up state (this is a copy of WebSocket.terminate(), minus the part that calls closed())
+            try:
+                self.close_connection()
+                self.stream._cleanup()
+            except:
+                pass
+            self.stream = None
+            self.environ = None
+
+            logger.warn("Server restart, reconnecting...")
+            self.reconnect()
+        else:
+            WebSocketBaseClient.terminate(self)
+
     def closed(self, code, reason):
         self.closed_code, self.closed_reason = code, reason
 
@@ -87,6 +116,17 @@ class DXJobLogStreamClient(WebSocketBaseClient):
     def received_message(self, message):
         message = json.loads(message.__unicode__())
 
+        if "job" in message and "level" in message and "line" in message:
+            last_line = self.last_seen_log_lines[message["job"]].get(message["level"], 0)
+            if last_line < message["line"]:
+                self.last_seen_log_lines[message["job"]][message["level"]] = message["line"]
+                if self.skipped_messages > 0:
+                    logger.warn("Skipped {} seen messages".format(self.skipped_messages))
+                    self.skipped_messages = 0
+            else:
+                self.skipped_messages += 1
+                return
+
         if self.print_job_info and 'job' in message and message['job'] not in self.seen_jobs:
             self.seen_jobs[message['job']] = dxpy.describe(message['job'])
             print(get_find_executions_string(self.seen_jobs[message['job']], has_children=False, show_outputs=False))
