@@ -408,8 +408,10 @@ class TestDXBashHelpers(DXTestCase):
         self.run_test_app_locally('deepdirs', [])
 
     def test_basic(self):
+        '''Tests upload/download helpers
+
+        '''
         # Make a couple files for testing
-        print("testing upload/download helpers")
         dxpy.upload_string("1234", wait_on_close=True, name="A.txt")
 
         # this invocation should fail with a CLI exception
